@@ -1,7 +1,12 @@
 import os
 import shutil
-directory = 'C:\\dev\\projects\\halo\halo-cli\\tests\\gen4\\BIAN_APIs_Release9.0'
-dest = 'C:\\dev\\projects\\halo\halo-cli\\tests\\gen4\\BIAN9'
+import sys
+
+#directory = 'C:\\dev\\projects\\halo\halo-cli\\tests\\gen4\\BIAN_APIs_Release9.0'
+#dest = 'C:\\dev\\projects\\halo\halo-cli\\tests\\gen4\\BIAN9'
+
+directory = sys.argv[1]
+dest = sys.argv[2]
 do_copy = False
 #[print(x[0]) for x in os.walk(directory)]
 cnt = 1
